import { IAccountsCommonConfiguration, ISession, IUser, IPassword, ICreateUser, ILoginUserIdentity } from '@identity-stack/core';
import { PROVIDERS_NAME } from '../constants';
import { PrepareMailFunction, SendMailFunction } from './email';
export declare type PasswordAuthenticator = (user: ILoginUserIdentity, password: IPassword) => Promise<any>;
export declare type ResumeSessionValidator = (user: IUser, session: ISession) => Promise<any>;
export interface ITokenConfig {
    accessToken?: {
        expiresIn: number;
    };
    codeToken?: {
        expiresIn: number;
    };
    refreshToken?: {
        expiresIn: number;
    };
}
export declare type UserObjectSanitizerFunction = (user: IUser, omitFunction: (userDoc: object) => IUser, pickFunction: (userDoc: object) => IUser) => any;
export interface IOAuthProvider {
    clientID: string;
    clientSecret: string;
    [key: string]: string;
}
export interface IAuthOptions {
    tokenHost?: string;
    callback?: string;
    db?: {
        timeToCheckExpiredTokens: number;
    };
    session?: {
        maxAge: number;
        secret: string;
    };
}
export interface IAuthorizationServerConfiguration extends IAccountsCommonConfiguration, IServerConfiguration {
    tokenSecret?: string;
    tokenConfigs?: ITokenConfig;
    passwordAuthenticator?: PasswordAuthenticator;
    resumeSessionValidator?: ResumeSessionValidator;
    prepareMail?: PrepareMailFunction;
    sendMail?: SendMailFunction;
    email?: object;
    emailTokensExpiry?: number;
    validateNewUser?: (user: ICreateUser) => Promise<boolean>;
    userObjectSanitizer?: UserObjectSanitizerFunction;
    allowedLoginFields?: string[];
    providers: Map<(keyof typeof PROVIDERS_NAME), IOAuthProvider>;
    auth: IAuthOptions;
}
export interface IServerConfiguration {
    providers: Map<(keyof typeof PROVIDERS_NAME), IOAuthProvider>;
}
