/// <reference types="bunyan" />
import { IIdentityService, IUserCreationResponse, IChangePasswordRequest, IForgotPasswordResponse, IDataContext, IForgotPasswordRequest, ILoginRequest, IResetPasswordRequest, IUserCreationRequest, IUserRegistrationResponse, IUserRegistrationRequest, IVerifyUserRequest, IVerifyEmailRequest, IUserRepository, ITokenRepository, IVerificationTokenGenerator } from '../interfaces';
import { IProfile } from '@identity-stack/core';
import { IUser } from '@identity-stack/core';
import { VersioningHasher } from '../security';
import * as Logger from 'bunyan';
export declare class IdentityService implements IIdentityService {
    private userRepository;
    private tokenRepository;
    private verificationTokenGenerator;
    private hasher;
    private logger;
    constructor(userRepository: IUserRepository, tokenRepository: ITokenRepository, verificationTokenGenerator: IVerificationTokenGenerator, hasher: VersioningHasher, logger: Logger);
    changePassword: ({username, oldPassword, newPassword}: IChangePasswordRequest, dataContext?: IDataContext) => Promise<void>;
    forgotPassword: ({username}: IForgotPasswordRequest, dataContext?: IDataContext) => Promise<IForgotPasswordResponse>;
    login: ({username, password}: ILoginRequest, dataContext?: IDataContext) => Promise<IUser | null>;
    resetPassword: ({username, password, passwordResetToken}: IResetPasswordRequest, dataContext?: IDataContext) => Promise<void>;
    createUser: (creationRequest: IUserCreationRequest, dataContext?: IDataContext) => Promise<IUserCreationResponse>;
    registerUser: ({username, password, email, ...attributes}: IUserRegistrationRequest, dataContext?: IDataContext) => Promise<IUserRegistrationResponse>;
    verifyUser: ({username, password, verificationToken}: IVerifyUserRequest, dataContext?: IDataContext) => Promise<void>;
    verifyEmail: ({username, email, verificationToken}: IVerifyEmailRequest, dataContext?: IDataContext) => Promise<void>;
    getProfileById: (id: string) => Promise<IProfile | null>;
    updateProfile: (id: string) => Promise<number>;
}
